@@ -1,9 +1,6 @@
 package Text::ANSITable::StyleSet::AltRow;
 
-our $DATE = '2021-08-09'; # DATE
-our $VERSION = '0.604'; # VERSION
-
-use 5.010;
+use 5.010001;
 use Moo;
 use namespace::clean;
 
@@ -12,6 +9,11 @@ has even_bgcolor => (is => 'rw');
 has odd_fgcolor  => (is => 'rw');
 has even_fgcolor => (is => 'rw');
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-08-27'; # DATE
+our $DIST = 'Text-ANSITable'; # DIST
+our $VERSION = '0.605'; # VERSION
+
 sub summary {
     "Set different foreground and/or background color for odd/even rows";
 }
@@ -56,7 +58,7 @@ Text::ANSITable::StyleSet::AltRow - Set different foreground and/or background c
 
 =head1 VERSION
 
-This document describes version 0.604 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2021-08-09.
+This document describes version 0.605 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2021-08-27.
 
 =for Pod::Coverage ^(summary|apply)$
 
@@ -78,18 +80,27 @@ Please visit the project's homepage at L<https://metacpan.org/release/Text-ANSIT
 
 Source repository is at L<https://github.com/perlancar/perl-Text-ANSITable>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-ANSITable>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2021, 2020, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
@@ -97,4 +108,12 @@ This software is copyright (c) 2021, 2020, 2018, 2017, 2016, 2015, 2014, 2013 by
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-ANSITable>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
